@@ -37,7 +37,7 @@ from datetime import datetime, timedelta
 
 import cron
 
-__version__='0.1.6'
+__version__='0.1.7'
 last_version_url='http://www.magikmon.com/download/mkbackup_last.txt'
 
 windows_codepage='cp1252'
@@ -363,25 +363,34 @@ class NtBackup:
         
         status+='selection=%s\r\n' % job.get('selection')
         status+='target=%s\r\n' % target
-        stat=os.stat(target)
-        status+='target_size=%d\r\n' % stat.st_size
-        status+='target_mtime_epoch=%d\r\n' % stat.st_mtime
-        status+='target_mtime=%s\r\n' % time.ctime(stat.st_mtime)
+        try:
+            stat=os.stat(target)
+        except Exception, e:
+            log.error('checking target file: %s', e)
+            status+='target=%s\r\n' % e
+        else:
+            status+='target_size=%d\r\n' % stat.st_size
+            status+='target_mtime_epoch=%d\r\n' % stat.st_mtime
+            status+='target_mtime=%s\r\n' % time.ctime(stat.st_mtime)
         
         #import ctypes
         #free_bytes = ctypes.c_ulonglong(0)
         #ctypes.windll.kernel32.GetDiskFreeSpaceExW(ctypes.c_wchar_p(target_dir), None, None, ctypes.pointer(free_bytes))
         #print free_bytes.value
 
-        import win32file
-        free_bytes, total_bytes, total_free_bytes=win32file.GetDiskFreeSpaceEx(target_dir)
-        status+='target_free_space=%d\r\n' % total_free_bytes
+        try:
+            import win32file
+            free_bytes, total_bytes, total_free_bytes=win32file.GetDiskFreeSpaceEx(target_dir)
+        except Exception, e:
+            log.error('checking target directory: %s', e)
+            status+='target_free_space=%s\r\n' % e
+        else:
+            status+='target_free_space=%d\r\n' % total_free_bytes
 
         status+='start_epoch=%d\r\n' % start
         status+='end_epoch=%d\r\n' % end
         status+='cmdline=%s\r\n' % cmdline
 
-
         for line in status.split('\n'):
             if line:
                 log.info('    %s', line)
@@ -390,17 +399,21 @@ class NtBackup:
         # dir of target directory
         #
         if True:
-            dir_out=u'  epoch   |          time          |      size     |    filename\r\n'
-            for filename in os.listdir(target_dir):
-                full_filename=os.path.join(target_dir, filename)
-                stat=os.stat(full_filename)
-                if os.path.isdir(full_filename):
-                    size='<DIR>'
-                else:
-                    size='%15d' % stat.st_size 
-                dir_out+='%d %s %15s %s\r\n' % (stat.st_mtime, time.ctime(stat.st_mtime), size, filename)
-                if last<current:
-                    logfile, last=full_filename, current
+            try: 
+                dir_out=u'  epoch   |          time          |      size     |    filename\r\n'
+                for filename in os.listdir(target_dir):
+                    full_filename=os.path.join(target_dir, filename)
+                    stat=os.stat(full_filename)
+                    if os.path.isdir(full_filename):
+                        size='<DIR>'
+                    else:
+                        size='%15d' % stat.st_size 
+                    dir_out+='%d %s %15s %s\r\n' % (stat.st_mtime, time.ctime(stat.st_mtime), size, filename)
+                    if last<current:
+                        logfile, last=full_filename, current
+            except Exception, e:
+                log.error('listing target directory: %s', e)
+                
         else: # OLD code, but use CP850 in my XP FR_en
             args=[ os.environ['comspec'], '/u', '/c', 'dir', target_dir ]
             pargs=convert_args_into_windows_codepage(args)
@@ -596,7 +609,7 @@ class Destinations:
 # Parse the command line
 #
 parser=parser=OptionParser(version='%%prog %s' % __version__ )
-parser.set_usage=('%prog [options] command [job..]\n'+
+parser.set_usage('%prog [options] command [job..]\n\n'
                   '\tcommand in "backup", "check", "checkmail"')
 
 parser.add_option("-c", "--config", dest="config", default='mkbackup.ini', help="use another ini file", metavar="config.ini")
@@ -632,13 +645,14 @@ if len(cmd_args)<2:
     parser.error('no "command" set')
     
 command=cmd_args[1]
+if command not in ('backup', 'check', 'checkmail'):
+    parser.error('invalid command "%s"' % command)
+
 job_list=cmd_args[2:]
 
 if not job_list:
     parser.error('no "job"')
 
-if command not in ('backup', 'check', 'checkmail'):
-    parser.error('invalid command "%s"' % command)
 #
 # load the configuration file
 #
@@ -666,7 +680,7 @@ if boolean.get(check_for_update.lower(), None)!=False:
                 log.warning(line)
         log.warning('!'*60)
 
-err=0
+err, failed_job=0, job_list[:]
 for job_name in job_list:
     try:
         program=config.get(job_name, 'program')
@@ -680,8 +694,12 @@ for job_name in job_list:
         if not program in archivers:
             log.error('program "%s" unknow in job "%s"', program, job_name)
             err+=1
+        else:
+            failed_job.remove(job_name)
+            
 
 if err>0:
+    parser.error('in jobs: %s' % ' '.join(failed_job))
     sys.exit(3)
 
 for job_name in job_list:
